@@ -7,19 +7,18 @@
  *
  *  Dec 2005
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
@@ -30,7 +29,7 @@
 #include "filter.h"
 #include "PTcommon.h"
 #include "ColourBrightness.h"
-#include "pt_stdint.h"
+#include <stdint.h>
 
 #include "tiffio.h"
 #include <assert.h>
@@ -38,12 +37,12 @@
 
 #include "pttiff.h"
 
-
-#ifdef _MSC_VER
-
+#ifdef WIN32
+#if defined _MSC_VER && _MSC_VER < 1900
 // MSVC doesn't support round()
 //#define round(x) ( (int) (x+0.5) )
 #define round(x) (int)(x)
+#endif // _MSC_VER
 
 // MSVC wants htons() to be a library function
 // here we define it as a macro instead
@@ -57,18 +56,21 @@
 #define ntohs(A) (A)
 #define ntohl(A) (A)
 #elif defined(LITTLE_ENDIAN) && !defined(BIG_ENDIAN)
-#define htons(A) (((uint16)(A) & 0xff00) >> 8 | ((uint16)(A) & 0x00ff) << 8 )
-#define htonl(A) ((((uint32)(A) & 0xff000000) >> 24) | \
-((uint32)(A) & 0x00ff0000) >> 8 | \
-((uint32)(A) & 0x0000ff00) << 8 | \
-((uint32)(A) & 0x000000ff) << 24)
+#define htons(A) (((uint16_t)(A) & 0xff00) >> 8 | ((uint16_t)(A) & 0x00ff) << 8 )
+#define htonl(A) ((((uint32_t)(A) & 0xff000000) >> 24) | \
+((uint32_t)(A) & 0x00ff0000) >> 8 | \
+((uint32_t)(A) & 0x0000ff00) << 8 | \
+((uint32_t)(A) & 0x000000ff) << 24)
 #define ntohs htons
 #define ntohl htohl
 #else
 #error "Either BIG_ENDIAN or LITTLE_ENDIAN must be #defined, but not both."
 #endif
-
-#endif  //def _MSC_VER
+#elif defined (__has_include)
+#if __has_include(<arpa/inet.h>)
+#include <arpa/inet.h>
+#endif
+#endif  //def WIN32
 
 
 
@@ -94,7 +96,6 @@ magnolia_struct *InitializeMagnolia(int numberImages, int size, calla_function p
   int i; 
   magnolia_struct *magnolia = NULL;
   double *ptrDouble;
-  int var04;
   double var16;
   int ecx;
 
@@ -104,8 +105,6 @@ magnolia_struct *InitializeMagnolia(int numberImages, int size, calla_function p
     
   }
   
-  var04 = size - 1;
-  
   var16 = (size -1 ) / 255.0; /// shouldn't this be a 256?
   
   for (i=0; i < numberImages; i++) {
@@ -148,11 +147,9 @@ int RemapPoint(int value, double mapTable[])
   double deltaNext;
 
   double var48;
-  int var44;
 
   double tablePrevValue;
   double tableNextValue;
-  int tempInt;
   int nextValueInt;
   int prevValueInt;
 
@@ -190,8 +187,6 @@ int RemapPoint(int value, double mapTable[])
   if (fabs(tableNextValue - tablePrevValue) <= 2.0) {
     // if the difference |f(value - 1)  -f(value+1) is too small
 
-    tempInt =  (int)mapTable[value];
-
     if ((int)mapTable[value] == 0xff ) {
       return 0xff;
     }
@@ -245,7 +240,6 @@ int RemapPoint(int value, double mapTable[])
   edx = prevValueInt;
 
   var48 = 0;
-  var44 = 0;
 
   //  if ( %edx > %nextValueInt ) /// [(int)tablePrevValue] > [(int)tableNextValue] 
   while ( edx <= nextValueInt ) { /// [(int)tablePrevValue] > [(int)tableNextValue] 
@@ -536,7 +530,7 @@ int OutputCurves(int index, magnolia_struct *curves, int typeOfCorrection,
   // actual name. This is not done yet
 
   strncpy(outputFileName, panoFileName->name, 500);
-  sprintf(temp, "%04d", index);
+  snprintf(temp, 8, "%04d", index);
   strcat(outputFileName, temp);
 
   panoReplaceExt(outputFileName, curveExtension[curveType-1]); 
@@ -596,7 +590,6 @@ void ColourBrightness(  fullPath *fullPathImages,  fullPath *outputFullPathImage
                         int counterImages, int indexReferenceImage, int parm3, int createCurvesType)
 {
 
-  histograms_struct * ptrHistograms;
   histograms_struct * ptrHistograms2;
   int numberHistograms;
   int index;
@@ -623,8 +616,6 @@ void ColourBrightness(  fullPath *fullPathImages,  fullPath *outputFullPathImage
   if ( calla.ptrHistograms == 0 )
     return ;
 
-  ptrHistograms = calla.ptrHistograms;
-
   fprintf(debugFile, "\nQuality before optimization:\n");
 
   //  printf("\nQuality before optimization:\n");
@@ -728,7 +719,7 @@ void ColourBrightness(  fullPath *fullPathImages,  fullPath *outputFullPathImage
 
   for (index = 0;  index <counterImages; index++ ) {
 
-    sprintf(string, "%d", index * 100 / counterImages);
+    snprintf(string, sizeof(string)-1, "%d", index * 100 / counterImages);
 
     if ( ptQuietFlag == 0 ) {
 
@@ -799,10 +790,8 @@ void FreeHistograms(histograms_struct *ptrHistograms, int count)
 int CorrectFileColourBrightness(fullPath *inPath, fullPath *outPath, magnolia_struct *magnolia, int parm3)
 {
   Image image;
-  char tempString[512];
   if (panoTiffRead (&image, inPath->name) == 0) {
-    sprintf(tempString, "Could not read TIFF file %s", inPath->name);
-    PrintError(tempString);
+    PrintError("Could not read TIFF file %s", inPath->name);
     return -1;
   }   
 
@@ -1221,19 +1210,18 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
   histograms_struct *ptrHistograms; //     << arrays of n * (n-1)/2 daisies
   int bytesPerLine;
   int  bitsPerPixel;
-  unsigned char *imagesDataBuffer; // numberOfImages * bytesPerLine
+  unsigned char *imagesDataBuffer = 0; // numberOfImages * bytesPerLine
   int bytesPerPixel;
   int  currentPixel;
   int currentRow;
   int otherImage;
   int currentImage;
   TIFF **ptrTIFFs = NULL;
-  uint16 samplesPerPixel;
-  uint16 bitsPerSample;
-  uint32 imageLength;
-  uint32 imageWidth;
+  uint16_t samplesPerPixel;
+  uint16_t bitsPerSample;
+  uint32_t imageLength;
+  uint32_t imageWidth;
   char  tempString[512];
-  char  tempString2[512];
   int *ptrInt;
   histograms_struct * currentHistogram;
   histograms_struct * saveReturnValue;
@@ -1286,8 +1274,7 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
     }
     
     if ((ptrTIFFs[currentImage] = TIFFOpen(tempString, "r")) == NULL) {
-      sprintf(tempString2, "Could not open TIFF file [%s]", tempString);
-      PrintError(tempString2);
+      PrintError("Could not open TIFF file [%s]", tempString);
       saveReturnValue = 0;
       goto Exit;
     }
@@ -1366,7 +1353,7 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
 
       // This probably means every 2 percent update progress
       
-      sprintf(tempString, "%d", (int)(currentRow * 100/imageLength));
+      snprintf(tempString, sizeof(tempString)-1, "%d", (int)(currentRow * 100/imageLength));
       
       if ( ptQuietFlag == 0 ) {
         if (Progress(_setProgress, tempString) == 0) {
@@ -1415,7 +1402,6 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
 
       unsigned char *ptrPixel;
       unsigned char *ptrOtherPixel;
-      int ecx;
 
       // We process each currentHistogram
       currentHistogram = ptrHistograms;
@@ -1425,8 +1411,6 @@ histograms_struct *ReadHistograms (fullPath *fullPathImages, int numberImages)
       ptrPixel = ptrCurrentPixelLineBuffer;
       assert(ptrPixel < imagesDataBuffer + numberImages * bytesPerLine);
 
-      ecx = numberImages;
-
       // for each pixel of each line of each image...
       for (currentImage = 0; currentImage < numberImages ; currentImage++, ptrPixel+= bytesPerLine) {
 
@@ -1926,7 +1910,6 @@ void CorrectImageColourBrigthness(Image *image, magnolia_struct *magnolia, int p
   unsigned char *pixel;
   int edi;
   double * (mappingCurves[6]);
-  int edx;
   unsigned char *ptrPixel;
   int channel;
   int level;
@@ -1970,8 +1953,6 @@ void CorrectImageColourBrigthness(Image *image, magnolia_struct *magnolia, int p
 
     currentRow = 0;
     
-    edx = currentRow;
-    
     while ( currentRow < image->height) {
 
       currentPixel = 0;
