@@ -2,28 +2,27 @@
  *  ptstitch.c
  *
  *  Routines related to stitching and creation of alpha channels
- * 
+ *
  *  Copyright Helmut Dersch and Daniel M. German
- *  
+ *
  *  Aug 2006
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
- * 
+ *
  */
 
 #include <assert.h>
@@ -281,7 +280,7 @@ int panoStitchCreateMaskMapFiles(fullPath * inputFiles, fullPath * maskFiles,
     // for each image, create merging mask and save to temporal file
     for (index = 0; index < numberImages; index++) {
 
-        sprintf(tempString, "%d", index * 100 / numberImages);
+        snprintf(tempString, sizeof(tempString)-1, "%d", index * 100 / numberImages);
 
         // Do progress
         if (ptQuietFlag == 0) {
@@ -726,7 +725,7 @@ int panoStitchCreateAlphaChannels(fullPath * masksNames,
         // Update progress
         if (ptQuietFlag == 0) {
             if (fullSizeRowIndex == (fullSizeRowIndex / 20) * 20) {
-                sprintf(tempString, "%lu",
+                snprintf(tempString, sizeof(tempString)-1, "%lu",
                         (long unsigned) fullSizeRowIndex * 100 /
                         fullImageHeight);
                 if (Progress(_setProgress, tempString) == 0) {
@@ -850,7 +849,7 @@ int panoStitchReplaceMasks(fullPath * inputFiles, fullPath * outputFiles,
     for (i = 0; i < numberImages; i++) {
         fullPath withAlphaChannel;
 
-        sprintf(tempString, "%d", 100 * i / numberImages);
+        snprintf(tempString, sizeof(tempString)-1, "%d", 100 * i / numberImages);
 
         if (ptQuietFlag == 0) {
             if (Progress(_setProgress, tempString) == 0) {
@@ -1013,11 +1012,11 @@ static void panoStitchBlendLayers8Bit(unsigned char **imageDataBuffers, int coun
                 for (index = 0; index < 3; index++) {
                     colours[index] += (*(ptrPixel + index) * alphaContribution) / 0xff; // 
 
-                    if (!(colours[index] >= 0 && colours[index] <= 0xff)) {
+                    if (!(colours[index] <= 0xff)) {
                         printf("PPPPPPPPPPPPPPPPPanic %d index [%d]\n",
                                colours[index], index);
                     }
-                    assert(colours[index] >= 0 && colours[index] <= 0xff);
+                    assert(colours[index] <= 0xff);
                 }
 
                 // We don't need to continue if the alpha channel is at the max
@@ -1057,7 +1056,7 @@ static void panoStitchBlendLayers16Bit(unsigned char **imageDataBuffers, int cou
     unsigned int rowOffset;
 
     uint16_t *u16ResultBuffer = (uint16_t *) resultBuffer;
-    uint16_t **u16ImageDataBuffers = (uint16 **) imageDataBuffers;
+    uint16_t **u16ImageDataBuffers = (uint16_t **) imageDataBuffers;
 
     currentLine = 0;
 
@@ -1141,7 +1140,7 @@ static void panoStitchBlendLayers16Bit(unsigned char **imageDataBuffers, int cou
 
                 for (index = 0; index < 3; index++) {
                     colours[index] += (*(ptrPixel + index) * alphaContribution) / 0xffff;       // 
-                    if (!(colours[index] >= 0 && colours[index] <= 0xffff)) {
+                    if (!(colours[index] <= 0xffff)) {
                         printf("PPPPPPPPPPPPPPPPPanic %lld index [%d]\n",
                                colours[index], index);
                     }
