@@ -100,7 +100,7 @@ void _SetDistance ( Image* im, Image* pano, PTRect *theRect, int showprogress )
 		if( showprogress && skip == 5 )
 		{
 			
-			sprintf( percent, "%d", (int) (dist* 100)/255) ;
+			snprintf( percent, 8, "%d", (int) (dist* 100)/255) ;
 			if( ! Progress( _setProgress, percent ) )
 						return;
 			skip = 0;
@@ -210,7 +210,7 @@ void _SetDistanceImage ( Image* im, Image* pano, PTRect *theRect, int showprogre
 		if( showprogress && skip == 5 )
 		{
 			
-			sprintf( percent, "%d", (int) (dist* 100)/255) ;
+			snprintf( percent, 8, "%d", (int) (dist* 100)/255) ;
 			if( ! Progress( _setProgress, percent ) )
 						return;
 			skip = 0;
@@ -378,11 +378,10 @@ void _mergeAlpha ( Image *im, unsigned char *alpha, int feather, PTRect *theRect
 	register int 			x,y;
 	double 				sfactor;
 	unsigned char			*data = *(im->data), *idata, *adata;
-	int				channels, BitsPerChannel,bpp;
+	int				BitsPerChannel,bpp;
 	Image				aImage;	 // Dummy for transfering alpha data
 	
 	
-	GetChannels( im, channels );
 	GetBitsPerChannel( im, BitsPerChannel );
 	bpp = im->bitsPerPixel/8;
 
