@@ -6,32 +6,30 @@
  *
  *  May 2005
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
  * 
  */
 
-#define PT_TIFF_DUMP_USAGE "PTtiffdump [options] <inputFile> <outputFile>\n\n"\
+#define PT_TIFF_DUMP_USAGE "PTtiffdump [options] <inputFile1> <inputFile2>\n\n"\
                          "Options:\n"\
-                         "-o\t\tOverwrite output file if it exists\n"\
 			 "\t-q\t\tQuiet run\n\t-h\t\tShow this message\n"\
                          "\n"
 
-#define PT_TIFF_DUMP_VERSION "PTuncrop Version " VERSION ", by Daniel M German\n"
+#define PT_TIFF_DUMP_VERSION "PTtiffdump Version " VERSION ", by Daniel M German\n"
 
 #include <assert.h>
 #include <stdio.h>
@@ -75,7 +73,6 @@ int Compare(unsigned char *data1,
 int main(int argc,char *argv[])
 {
   int opt;
-  int overwrite = 0;
   int filesCount;
   char *inputFile, *otherFile;
 
@@ -93,14 +90,10 @@ int main(int argc,char *argv[])
 
   while ((opt = getopt(argc, argv, "ohq")) != -1) {
 
-// o overwrite
 // h       -> help
 // q       -> quiet?
     
     switch(opt) {  // fhoqs        f: 102 h:104  111 113 115  o:f:hsq
-    case 'o':
-      overwrite = 1;
-      break;
     case 'q':
       ptQuietFlag = 1;
       break;
